==> plasma-bigscreen-5.26.90.tar.xz: plasma-bigscreen-5.26.90/bin/plasma-bigscreen-x11.desktop.cmake <==
[Desktop Entry]
Exec=dbus-run-session ${CMAKE_INSTALL_FULL_BINDIR}/plasma-bigscreen-x11
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/plasma-bigscreen-x11
DesktopNames=KDE
Name=Plasma Bigscreen (X11)
Name[ar]=بلازما الشاشة الكبيرة (اكس11)
Name[az]=Plasma Böyük Ekran (X11)
Name[bg]=Plasma Bigscreen (X11)
Name[ca]=Plasma Bigscreen (X11)
Name[ca@valencia]=Plasma Bigscreen (X11)
Name[cs]=Plasma Bigscreen (X11)
Name[de]=Plasma Bigscreen (X11)
Name[en_GB]=Plasma Bigscreen (X11)
Name[es]=Plasma Bigscreen (X11)
Name[eu]=Plasma Bigscreen (X11)
Name[fi]=Plasma Bigscreen (X11)
Name[fr]=Grand écran de Plasma (X11)
Name[hu]=Plasma Bigscreen (X11)
Name[id]=Plasma Bigscreen (X11)
Name[it]=Plasma Bigscreen (X11)
Name[ka]=Plasma დიდ ეკრანზე (X11)
Name[ko]=Plasma 큰 화면(X11)
Name[nl]=Plasma Bigscreen (X11)
Name[nn]=Plasma Bigscreen (X11)
Name[pl]=Duży Ekran Plazmy (X11)
Name[pt]=Plasma para Grande Ecrã (X11)
Name[pt_BR]=Plasma Bigscreen (X11)
Name[ru]=Plasma Bigscreen (X11)
Name[sk]=Plasma Bigscreen (X11)
Name[sl]=Veliki zaslon Plasma (X11)
Name[sv]=Plasma storbildsskärm (X11)
Name[tr]=Plasma Büyük Ekran (X11)
Name[uk]=Плазма для великих екранів (X11)
Name[x-test]=xxPlasma Bigscreen (X11)xx
Name[zh_CN]=Plasma 大屏幕 (X11)
Comment=Plasma Bigscreen by KDE (X11)
Comment[ar]=بلازما الشاشة الكبيرة بواسطة كدي (اكس11)
Comment[az]=KDE tərəfindən Plasma Böyük Ekran (X11)
Comment[bg]=Plasma Bigscreen от KDE (X11)
Comment[ca]=Plasma Bigscreen, creat per la comunitat KDE (X11)
Comment[ca@valencia]=Plasma Bigscreen, creat per la comunitat KDE (X11)
Comment[cs]=Plasma Bigscreen od KDE (X11)
Comment[de]=Plasma Bigscreen von KDE (X11)
Comment[en_GB]=Plasma Bigscreen by KDE (X11)
Comment[es]=Plasma Bigscreen por KDE (X11)
Comment[eu]=Plasma Bigscreen, KDEk egina (X11)
Comment[fi]=Plasma Bigscreen KDE:ltä (X11)
Comment[fr]=Grand écran de Plasma par KDE (X11)
Comment[hu]=Plasma Bigscreen a KDE-től (X11)
Comment[id]=Plasma Bigscreen oleh KDE (X11)
Comment[it]=Plasma Bigscreen di KDE (X11)
Comment[ka]=Plasma დიდ ეკრანზე, KDE-სგან (X11)
Comment[ko]=KDE Plasma 큰 화면(X11)
Comment[nl]=Plasma Bigscreen door KDE (X11)
Comment[nn]=Plasma Bigscreen frå KDE (X11)
Comment[pl]=Duży Ekran Plazmy stworzony przez KDE (X11)
Comment[pt]=Plasma para Grande Ecrã do KDE (X11)
Comment[pt_BR]=Plasma Bigscreen do KDE (X11)
Comment[ru]=KDE Plasma Bigscreen (X11)
Comment[sk]=Plasma Bigscreen od KDE (X11)
Comment[sl]=Veliki zaslon Plasma v KDE (X11)
Comment[sv]=Plasma storbildsskärm av KDE (X11)
Comment[tr]=KDE tarafından yapılan Plasma Büyük Ekran (X11)
Comment[uk]=Плазма для великих екранів від KDE (X11)
Comment[x-test]=xxPlasma Bigscreen by KDE (X11)xx
Comment[zh_CN]=KDE Plasma 大屏幕 (X11)
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-bigscreen-5.27.3.tar.xz: plasma-bigscreen-5.27.3/bin/plasma-bigscreen-x11.desktop.cmake <==
[Desktop Entry]
Exec=dbus-run-session ${CMAKE_INSTALL_FULL_BINDIR}/plasma-bigscreen-x11
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/plasma-bigscreen-x11
DesktopNames=KDE
Name=Plasma Bigscreen (X11)
Name[ar]=بلازما الشاشة الكبيرة (اكس11)
Name[az]=Plasma Böyük Ekran (X11)
Name[bg]=Plasma Bigscreen (X11)
Name[ca]=Plasma Bigscreen (X11)
Name[ca@valencia]=Plasma Bigscreen (X11)
Name[cs]=Plasma Bigscreen (X11)
Name[de]=Plasma Bigscreen (X11)
Name[en_GB]=Plasma Bigscreen (X11)
Name[es]=Plasma Bigscreen (X11)
Name[eu]=Plasma Bigscreen (X11)
Name[fi]=Plasma Bigscreen (X11)
Name[fr]=Grand écran de Plasma (X11)
Name[hu]=Plasma Bigscreen (X11)
Name[id]=Plasma Bigscreen (X11)
Name[it]=Plasma Bigscreen (X11)
Name[ka]=Plasma დიდ ეკრანზე (X11)
Name[ko]=Plasma 큰 화면(X11)
Name[nl]=Plasma Bigscreen (X11)
Name[nn]=Plasma Bigscreen (X11)
Name[pl]=Duży Ekran Plazmy (X11)
Name[pt]=Plasma para Grande Ecrã (X11)
Name[pt_BR]=Plasma Bigscreen (X11)
Name[ru]=Plasma Bigscreen (X11)
Name[sk]=Plasma Bigscreen (X11)
Name[sl]=Veliki zaslon Plasma (X11)
Name[sv]=Plasma storbildsskärm (X11)
Name[tr]=Plasma Büyük Ekran (X11)
Name[uk]=Плазма для великих екранів (X11)
Name[x-test]=xxPlasma Bigscreen (X11)xx
Name[zh_CN]=Plasma 大屏幕 (X11)
Comment=Plasma Bigscreen by KDE (X11)
Comment[ar]=بلازما الشاشة الكبيرة بواسطة كِيدِي (اكس11)
Comment[az]=KDE tərəfindən Plasma Böyük Ekran (X11)
Comment[bg]=Plasma Bigscreen от KDE (X11)
Comment[ca]=Plasma Bigscreen, creat per la comunitat KDE (X11)
Comment[ca@valencia]=Plasma Bigscreen, creat per la comunitat KDE (X11)
Comment[cs]=Plasma Bigscreen od KDE (X11)
Comment[de]=Plasma Bigscreen von KDE (X11)
Comment[en_GB]=Plasma Bigscreen by KDE (X11)
Comment[es]=Plasma Bigscreen por KDE (X11)
Comment[eu]=Plasma Bigscreen, KDEk egina (X11)
Comment[fi]=Plasma Bigscreen KDE:ltä (X11)
Comment[fr]=Grand écran de Plasma par KDE (X11)
Comment[hu]=Plasma Bigscreen a KDE-től (X11)
Comment[id]=Plasma Bigscreen oleh KDE (X11)
Comment[it]=Plasma Bigscreen di KDE (X11)
Comment[ka]=Plasma დიდ ეკრანზე, KDE-სგან (X11)
Comment[ko]=KDE Plasma 큰 화면(X11)
Comment[nl]=Plasma Bigscreen door KDE (X11)
Comment[nn]=Plasma Bigscreen frå KDE (X11)
Comment[pl]=Duży Ekran Plazmy stworzony przez KDE (X11)
Comment[pt]=Plasma para Grande Ecrã do KDE (X11)
Comment[pt_BR]=Plasma Bigscreen do KDE (X11)
Comment[ru]=KDE Plasma Bigscreen (X11)
Comment[sk]=Plasma Bigscreen od KDE (X11)
Comment[sl]=Veliki zaslon Plasma v KDE (X11)
Comment[sv]=Plasma storbildsskärm av KDE (X11)
Comment[tr]=KDE tarafından yapılan Plasma Büyük Ekran (X11)
Comment[uk]=Плазма для великих екранів від KDE (X11)
Comment[x-test]=xxPlasma Bigscreen by KDE (X11)xx
Comment[zh_CN]=KDE Plasma 大屏幕 (X11)
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
